﻿using ConsoleTableExt;
using WorkTime.Models;
using System.Diagnostics;

namespace WorkTime
{
    class Program
    {
        public static void Main(string[] args)
        {
            string text;
            using (var sr = new StreamReader("HelloText.txt"))
            {
                text = sr.ReadToEnd();
            }

            using var context = new CourseContext();
            Controller controller = new(context);
            string operation = "";
            do
            {
                Console.WriteLine(text);
                operation = Console.ReadLine() ?? "";
                switch (operation)
                {
                    case "0":
                        break;
                    case "1":
                        controller.GetWorkers();
                        break;
                    case "2":
                        controller.GetProject();
                        break;
                    case "3":
                        controller.GetSalary();
                        break;
                    case "4":
                        controller.GetSalaryOnCurrentMonth();
                        break;
                    case "5":
                        controller.GetPosts();
                        break;
                    case "6":
                        Console.WriteLine("Введите Имя и id должности(1,2)");
                        Worker worker = new()
                        {
                            Name = Console.ReadLine(),
                            PostId = int.Parse(Console.ReadLine()),
                        };
                        controller.AddWorker(worker);
                        break;
                    case "7":
                        Test(controller, context);
                        break;
                    default:
                        Console.WriteLine("Некорректно введенный номер операции");
                        break;
                }
            } while (operation != "0");
        }
        public static void Test(Controller controller, CourseContext context)
        {
            Random r = new Random();
            string name = "";
            for (int i = 0; i < 7; i++)
                name += (char)r.Next(65, 89);
            Worker worker = new()
            {
                Name = name[..7],
                PostId = r.Next(1,2),            
            };

            var result = new[]
            {
                new { Name = "1", timems = MeasureTime(controller.GetWorkers)},
                new { Name = "2", timems = MeasureTime(controller.GetProject)},
                new { Name = "3", timems = MeasureTime(controller.GetSalary)},
                new { Name = "4", timems = MeasureTime(() => controller.GetSalaryOnCurrentMonth())},
                new { Name = "5", timems = MeasureTime(controller.GetPosts)},
                new { Name = "6", timems = MeasureTime(() => controller.AddWorker(worker))},
            }.ToList();
            ConsoleTableBuilder.From(result).ExportAndWriteLine();
        }

        public static double MeasureTime(Action action, int count = 10)
        {
            long sumTime = 0;
            Stopwatch stopwatch = new();
            for (int i = 0; i < count; i++)
            {
                stopwatch.Start();
                action.Invoke();
                stopwatch.Stop();
                sumTime += stopwatch.ElapsedMilliseconds;
            }
            return sumTime / count;
        }
    }
}